Skip to main contentModule search
Source - below
- Find elements positioned below an anchor.
- clickable
- Match clickable elements.
- compose
- Compose filters sequentially (pipeline).
- flatten_tree
- Flatten a tree node into a list of all descendant nodes.
- get_element_center
- Get center coordinates from boundsInScreen.
- has_text
- Match elements that have non-empty text.
- id_matches
- Match elements by resource ID.
- text_matches
- Match elements by text content (text, contentDescription, or hint).
- ElementFilter
- A filter function that takes a list of tree nodes and returns matching ones.